window.Gleam.initSearch([{"doc":"glormat","title":"glormat","content":"# glormat\n\nA simple, readable string formatting library for Gleam!\n\n[![Package Version](https://img.shields.io/hexpm/v/glormat)](https://hex.pm/packages/glormat)\n[![Hex Docs](https://img.shields.io/badge/hex-docs-ffaff3)](https://hexdocs.pm/glormat/)\n\n```sh\ngleam add glormat\n```\n```gleam\nimport gleam/io\nimport glormat.{assert_ok, replace, then, then_debug}\n\npub fn main() {\n  &quot;hello {object}, the {operation} is {result}&quot;\n    |&gt; replace(&quot;object&quot;, with: &quot;world&quot;)\n    |&gt; then(&quot;operation&quot;, with: &quot;sum&quot;)\n    |&gt; then_debug(&quot;result&quot;, with: 1 + 2)\n    |&gt; assert_ok\n    |&gt; io.println // hello world, the sum is 3\n}\n```\n\nFurther documentation can be found at &lt;https://hexdocs.pm/glormat&gt;.\n\n## Development\n\n```sh\ngleam run   # Run the project\ngleam test  # Run the tests\ngleam shell # Run an Erlang shell\n```\n","url":"index.html"},{"doc":"glormat","title":"assert_ok","content":"pub fn assert_ok(result: Result(String, Nil)) -&gt; String\n Assert that `result` is `Ok`, returning the contained `String`. This may be useful in cases where you as the programmer know that formatting will not fail, but the compiler does not.\nSynonyms:\nglormat.assert_ok\nglormat assert_ok","url":"glormat.html#assert_ok"},{"doc":"glormat","title":"debug","content":"pub fn debug(\n  in format_string: String,\n  replace label: String,\n  with data: a,\n) -&gt; Result(String, Nil)\n A wrapper for `format` that calls `string.inspect` on `data` before passing it in.\n\n This allows formatting with non-`String` data.\nSynonyms:\nglormat.debug\nglormat debug","url":"glormat.html#debug"},{"doc":"glormat","title":"format","content":"pub fn format(\n  in format_string: String,\n  replace label: String,\n  with data: String,\n) -&gt; Result(String, Nil)\n Replace all instances of `&quot;{label}&quot;` with `data` in the input string.\n\n To replace more labels, pipe this function into `then` or `then_debug`.\n\n If you want to use `format` in a pipeline, `replace` may be more concise.\n\n If the given label isn&#39;t found, this function returns `Error(Nil).`\n\n ## Examples\n\n \n let assert Ok(&quot;hello world&quot;) =\n   format(in: &quot;hello {object}&quot;, replace: &quot;object&quot;, with: &quot;world&quot;)\n \nSynonyms:\nglormat.format\nglormat format","url":"glormat.html#format"},{"doc":"glormat","title":"replace","content":"pub fn replace(\n  in format_string: String,\n  replace label: String,\n  with data: String,\n) -&gt; Result(String, Nil)\n An alias for `format` that may lend more readable code.\n\n ## Examples\n\n \n let assert Ok(&quot;hello world&quot;) =\n   &quot;hello {object}&quot;\n   |&gt; replace(&quot;object&quot;, with: &quot;world&quot;)\n \nSynonyms:\nglormat.replace\nglormat replace","url":"glormat.html#replace"},{"doc":"glormat","title":"then","content":"pub fn then(\n  in result: Result(String, Nil),\n  replace label: String,\n  with data: String,\n) -&gt; Result(String, Nil)\n If `result` is `Ok`, call `format` on the contained value, otherwise return the `Error`.\n\n ## Examples\n\n \n let assert Ok(&quot;hello world, how are you?&quot;) =\n   &quot;hello {object}, {question}?&quot;\n   |&gt; replace(&quot;object&quot;, with: &quot;world&quot;)\n   |&gt; then(&quot;question&quot;, with: &quot;how are you&quot;)\n \nSynonyms:\nglormat.then\nglormat then","url":"glormat.html#then"},{"doc":"glormat","title":"then_debug","content":"pub fn then_debug(\n  in result: Result(String, Nil),\n  replace label: String,\n  with data: a,\n) -&gt; Result(String, Nil)\n A wrapper for `then` that calls `string.inspect` on `data` before passing it in.\n This allows formatting with non-String data.\nSynonyms:\nglormat.then_debug\nglormat then_debug","url":"glormat.html#then_debug"},{"doc":"glormat","title":"glormat","content":"","url":"glormat.html"}]);